"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildDistFiles = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const klaw_1 = __importDefault(require("klaw"));
const path_1 = __importDefault(require("path"));
/**
 * @param basePath -
 * @returns true if the dist files process was successful
 */
async function buildDistFiles(basePath) {
    console.log("Build - started on dist files");
    let res;
    try {
        const pkgInfo = (await Promise.resolve(`${path_1.default.join(basePath, "package.json")}`).then(s => __importStar(require(s)))), libPackage = path_1.default.join(basePath, "package.dist.json"), distPath = path_1.default.join(basePath, pkgInfo.publishConfig?.directory ?? "dist");
        const data = await fs_extra_1.default.readFile(libPackage), text = data.toString(), libObj = JSON.parse(text);
        libObj.version = pkgInfo.version;
        if (pkgInfo.dependencies) {
            libObj.dependencies = JSON.parse(JSON.stringify(pkgInfo.dependencies).replaceAll("workspace:", ""));
        }
        else if (pkgInfo.peerDependencies) {
            libObj.peerDependencies = JSON.parse(JSON.stringify(pkgInfo.peerDependencies).replaceAll("workspace:", ""));
        }
        const jsonIndent = 2;
        await fs_extra_1.default.writeFile(libPackage, `${JSON.stringify(libObj, undefined, jsonIndent)}\n`, "utf8");
        console.log(`package.dist.json updated successfully to version ${pkgInfo.version}`);
        const rootFilesToCopy = [
            "LICENSE",
            "README.md",
            {
                source: "package.dist.json",
                destination: "package.json",
            },
        ];
        for (const file of rootFilesToCopy) {
            const src = path_1.default.join(basePath, typeof file === "string" ? file : file.source), dest = path_1.default.join(distPath, typeof file === "string" ? file : file.destination);
            await fs_extra_1.default.copyFile(src, dest);
        }
        const scriptsPath = path_1.default.join(basePath, "scripts"), distScriptsPath = path_1.default.join(distPath, "scripts");
        if ((await fs_extra_1.default.exists(scriptsPath)) && !(await fs_extra_1.default.exists(distScriptsPath))) {
            await fs_extra_1.default.mkdir(distScriptsPath);
            const installPath = path_1.default.join(scriptsPath, "install.js");
            if (await fs_extra_1.default.exists(installPath)) {
                await fs_extra_1.default.copyFile(installPath, path_1.default.join(distScriptsPath, "install.js"));
            }
        }
        for await (const file of (0, klaw_1.default)(distPath)) {
            if (file.stats.isDirectory()) {
                continue;
            }
            const contents = await fs_extra_1.default.readFile(file.path, "utf8");
            await fs_extra_1.default.writeFile(file.path, contents.replaceAll("__VERSION__", `"${pkgInfo.version}"`), "utf8");
        }
        /* for await (const file of klaw(path.join(distPath, "cjs"))) {
            await fs.rename(file.path, file.path.replace(/\.js$/, ".cjs"));
        }

        for await (const file of klaw(path.join(distPath, "esm"))) {
            await fs.rename(file.path, file.path.replace(/\.js$/, ".mjs"));
        } */
        await fs_extra_1.default.writeFile(path_1.default.join(distPath, "cjs", "package.json"), `{ "type": "commonjs" }`);
        await fs_extra_1.default.writeFile(path_1.default.join(distPath, "esm", "package.json"), `{ "type": "module" }`);
        await fs_extra_1.default.writeFile(path_1.default.join(distPath, "browser", "package.json"), `{ "type": "module" }`);
        res = true;
    }
    catch (e) {
        console.error(e);
        res = false;
    }
    console.log("Build - done on dist files");
    return res;
}
exports.buildDistFiles = buildDistFiles;
