"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDistStats = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
/**
 * @param folderPath - the path to the folder to get the stats for
 * @param bundlePath - the bundle path to get the bundle size for
 * @returns the given folder stats;
 */
async function getFolderStats(folderPath, bundlePath) {
    const stats = {
        bundleSize: 0,
        totalFiles: 0,
        totalFolders: 0,
        totalSize: 0,
    };
    if (!(await fs_extra_1.default.pathExists(folderPath))) {
        return stats;
    }
    const dir = await fs_extra_1.default.promises.opendir(folderPath), path = await Promise.resolve().then(() => __importStar(require("path")));
    for await (const dirent of dir) {
        const increment = 1;
        if (dirent.isDirectory()) {
            const subDirStats = await getFolderStats(path.join(folderPath, dirent.name), bundlePath);
            stats.totalFolders += subDirStats.totalFolders + increment;
            stats.totalFiles += subDirStats.totalFiles;
            stats.totalSize += subDirStats.totalSize;
        }
        else {
            const fileStats = await fs_extra_1.default.stat(path.join(folderPath, dirent.name));
            stats.totalFiles++;
            stats.totalSize += fileStats.size;
            if (bundlePath && path.join(folderPath, dirent.name) === bundlePath) {
                stats.bundleSize += fileStats.size;
            }
        }
    }
    return stats;
}
/**
 * Gets the stats for the dist folder
 * @param basePath - the base path to the project
 * @returns the stats for the dist folder
 */
async function getDistStats(basePath) {
    const path = await Promise.resolve().then(() => __importStar(require("path"))), distFolder = path.join(basePath, "dist"), pkgInfo = (await fs_extra_1.default.exists(path.join(distFolder, "package.json")))
        ? (await Promise.resolve(`${path.join(distFolder, "package.json")}`).then(s => __importStar(require(s))))
        : {}, bundlePath = (await fs_extra_1.default.exists(distFolder)) && pkgInfo.jsdelivr
        ? path.resolve(path.join(distFolder, pkgInfo.jsdelivr))
        : undefined;
    return await getFolderStats(distFolder, bundlePath);
}
exports.getDistStats = getDistStats;
