"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lint = void 0;
const eslint_1 = require("eslint");
/**
 * @param ci -
 * @returns true if the linting was successful
 */
async function lint(ci) {
    console.log("ESLint - started on src");
    let res;
    try {
        const eslint = new eslint_1.ESLint({
            baseConfig: {
                extends: ["@tsparticles/eslint-config"],
            },
            extensions: [".js", ".jsx", ".ts", ".tsx"],
            fix: !ci,
        });
        const results = await eslint.lintFiles(["src"]), errors = eslint_1.ESLint.getErrorResults(results);
        await eslint_1.ESLint.outputFixes(results);
        const formatter = await eslint.loadFormatter("stylish"), resultText = formatter.format(results), minimumLength = 0;
        if (errors.length > minimumLength) {
            const messages = errors.map(t => t.messages.map(m => `${t.filePath} (${m.line},${m.column}): ${m.message}`).join("\n"));
            throw new Error(messages.join("\n"));
        }
        console.log(resultText);
        res = true;
    }
    catch (e) {
        console.error(e);
        res = false;
    }
    console.log("ESLint - done on src");
    return res;
}
exports.lint = lint;
