"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildTS = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
/**
 * @param basePath -
 * @param file -
 * @returns the file content or undefined if the file doesn't exist
 */
async function readConfig(basePath, file) {
    const tsconfigPath = path_1.default.join(basePath, file);
    if (await fs_extra_1.default.pathExists(tsconfigPath)) {
        const data = await fs_extra_1.default.readFile(path_1.default.join(basePath, file));
        return data.toString();
    }
}
/**
 * @param basePath -
 * @param type -
 * @returns the exit code
 */
async function compile(basePath, type) {
    let options, data;
    switch (type) {
        case "browser":
            data = await readConfig(basePath, "tsconfig.browser.json");
            if (!data) {
                options = {
                    extends: "@tsparticles/tsconfig/tsconfig.browser.json",
                    compilerOptions: {
                        rootDir: "./src",
                        outDir: "./dist/browser",
                    },
                    include: ["./src"],
                };
            }
            break;
        case "cjs":
            data = await readConfig(basePath, "tsconfig.json");
            if (!data) {
                options = {
                    extends: "@tsparticles/tsconfig/tsconfig.json",
                    compilerOptions: {
                        rootDir: "./src",
                        outDir: "./dist/cjs",
                    },
                    include: ["./src"],
                };
            }
            break;
        case "esm":
            data = await readConfig(basePath, "tsconfig.module.json");
            if (!data) {
                options = {
                    extends: "@tsparticles/tsconfig/tsconfig.module.json",
                    compilerOptions: {
                        rootDir: "./src",
                        outDir: "./dist/esm",
                    },
                    include: ["./src"],
                };
            }
            break;
        case "types":
            data = await readConfig(basePath, "tsconfig.types.json");
            if (!data) {
                options = {
                    extends: "@tsparticles/tsconfig/tsconfig.types.json",
                    compilerOptions: {
                        rootDir: "./src",
                        outDir: "./dist/types",
                    },
                    include: ["./src"],
                };
            }
            break;
        case "umd":
            data = await readConfig(basePath, "tsconfig.umd.json");
            if (!data) {
                options = {
                    extends: "@tsparticles/tsconfig/tsconfig.umd.json",
                    compilerOptions: {
                        rootDir: "./src",
                        outDir: "./dist/umd",
                    },
                    include: ["./src"],
                };
            }
            break;
    }
    if (!data && !options) {
        return 2 /* ExitCodes.NoDataOrOptions */;
    }
    if (!options && data) {
        options = JSON.parse(data);
    }
    if (!options) {
        return 3 /* ExitCodes.NoOptions */;
    }
    const ts = await Promise.resolve().then(() => __importStar(require("typescript"))), parsed = ts.parseJsonConfigFileContent(options, ts.sys, basePath);
    if (!parsed) {
        return 4 /* ExitCodes.ParseError */;
    }
    const program = ts.createProgram(parsed.fileNames, parsed.options), emitResult = program.emit(), allDiagnostics = ts.getPreEmitDiagnostics(program).concat(emitResult.diagnostics);
    let failed = false;
    allDiagnostics.forEach(diagnostic => {
        failed = failed || diagnostic.category === ts.DiagnosticCategory.Error;
        if (diagnostic.file) {
            const startingPos = 0, { line, character } = ts.getLineAndCharacterOfPosition(diagnostic.file, diagnostic.start ?? startingPos), message = ts.flattenDiagnosticMessageText(diagnostic.messageText, "\n"), increment = 1;
            console.log(`${diagnostic.file.fileName} (${line + increment},${character + increment}): ${message}`);
        }
        else {
            console.log(ts.flattenDiagnosticMessageText(diagnostic.messageText, "\n"));
        }
    });
    const exitCode = emitResult.emitSkipped || failed ? 1 /* ExitCodes.EmitErrors */ : 0 /* ExitCodes.OK */;
    console.log(`TSC for ${type} done with exit code: '${exitCode}'.`);
    return exitCode;
}
/**
 * @param basePath -
 * @returns true if the build was successful
 */
async function buildTS(basePath) {
    console.log("Building TS files");
    let res = true;
    const types = ["browser", "cjs", "esm", "types", "umd"];
    for await (const type of types) {
        console.log(`Building TS files for ${type} configuration`);
        const exitCode = await compile(basePath, type);
        if (exitCode) {
            res = false;
            break;
        }
    }
    console.log("Building TS files done");
    return res;
}
exports.buildTS = buildTS;
