"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildCommand = void 0;
const commander_1 = require("commander");
const buildCommand = new commander_1.Command("build");
exports.buildCommand = buildCommand;
buildCommand.description("Build the tsParticles library using TypeScript");
buildCommand.option("-a, --all", "Do all build steps (default if no flags are specified) (same as -b -c -d -l -p -t)", false);
buildCommand.option("-b, --bundle", "Bundle the library using Webpack", false);
buildCommand.option("-c, --clean", "Clean the dist folder", false);
buildCommand.option("--ci", "Do all build steps for CI, no fixing files, only checking if they are formatted correctly", false);
buildCommand.option("-cd, --circular-deps", "Check for circular dependencies", false);
buildCommand.option("-d, --dist", "Build the dist files", false);
buildCommand.option("-l, --lint", "Lint the source files", false);
buildCommand.option("-p, --prettify", "Prettify the source files", false);
buildCommand.option("-t, --tsc", "Build the library using TypeScript", false);
buildCommand.argument("[path]", `Path to the project root folder, default is "src"`, "src");
buildCommand.action(async (argPath) => {
    const opts = buildCommand.opts(), ci = !!opts.ci, all = !!opts.all || (!opts.bundle && !opts.clean && !opts.dist && !opts.lint && !opts.prettify && !opts.tsc), doBundle = all || !!opts.bundle, circularDeps = all || !!opts.circularDeps, clean = all || !!opts.clean, distfiles = all || !!opts.dist, doLint = all || !!opts.lint, prettier = all || !!opts.prettify, tsc = all || !!opts.tsc;
    const basePath = process.cwd(), { getDistStats } = await Promise.resolve().then(() => __importStar(require("./build-diststats.js"))), oldStats = await getDistStats(basePath);
    if (clean) {
        const { clearDist } = await Promise.resolve().then(() => __importStar(require("./build-clear.js")));
        await clearDist(basePath);
    }
    const path = await Promise.resolve().then(() => __importStar(require("path"))), srcPath = path.join(basePath, argPath), fs = await Promise.resolve().then(() => __importStar(require("fs-extra")));
    if (!(await fs.pathExists(srcPath))) {
        throw new Error("Provided path does not exist");
    }
    let canContinue = true;
    if (canContinue && prettier) {
        const { prettifySrc } = await Promise.resolve().then(() => __importStar(require("./build-prettier.js")));
        canContinue = await prettifySrc(basePath, srcPath, ci);
    }
    if (canContinue && doLint) {
        const { lint } = await Promise.resolve().then(() => __importStar(require("./build-eslint.js")));
        canContinue = await lint(ci);
    }
    if (canContinue && tsc) {
        const { buildTS } = await Promise.resolve().then(() => __importStar(require("./build-tsc.js")));
        canContinue = await buildTS(basePath);
    }
    if (canContinue && circularDeps) {
        const { buildCircularDeps } = await Promise.resolve().then(() => __importStar(require("./build-circular-deps.js")));
        canContinue = await buildCircularDeps(basePath);
    }
    if (canContinue && doBundle) {
        const { bundle } = await Promise.resolve().then(() => __importStar(require("./build-bundle.js")));
        canContinue = await bundle(basePath);
    }
    if (canContinue && prettier) {
        const { prettifyReadme, prettifyPackageJson, prettifyPackageDistJson } = await Promise.resolve().then(() => __importStar(require("./build-prettier.js")));
        canContinue = await prettifyReadme(basePath, ci);
        canContinue = await prettifyPackageJson(basePath, ci);
        canContinue = await prettifyPackageDistJson(basePath, ci);
    }
    if (canContinue && distfiles) {
        const { buildDistFiles } = await Promise.resolve().then(() => __importStar(require("./build-distfiles.js")));
        canContinue = await buildDistFiles(basePath);
    }
    if (!canContinue) {
        throw new Error("Build failed");
    }
    const newStats = await getDistStats(basePath), diffSize = newStats.totalSize - oldStats.totalSize, bundleDiffSize = newStats.bundleSize - oldStats.bundleSize, minSize = 0, bundleSizeIncreased = bundleDiffSize > minSize, outputFunc = bundleSizeIncreased ? console.warn : console.info, texts = [
        !bundleDiffSize
            ? "Bundle size unchanged"
            : `Bundle size ${bundleSizeIncreased ? "increased" : "decreased"} from ${oldStats.bundleSize} to ${newStats.bundleSize} (${Math.abs(bundleDiffSize)}B)`,
        !diffSize
            ? "Size unchanged"
            : `Size ${diffSize > minSize ? "increased" : "decreased"} from ${oldStats.totalSize} to ${newStats.totalSize} (${Math.abs(diffSize)}B)`,
        `Files count changed from ${oldStats.totalFiles} to ${newStats.totalFiles} (${newStats.totalFiles - oldStats.totalFiles})`,
        `Folders count changed from ${oldStats.totalFolders} to ${newStats.totalFolders} (${newStats.totalFolders - oldStats.totalFolders})`,
    ];
    console.log("Build finished successfully!");
    for (const text of texts) {
        outputFunc(text);
    }
});
