"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pluginCommand = void 0;
const file_utils_1 = require("../../utils/file-utils");
const prompts_1 = __importDefault(require("prompts"));
const commander_1 = require("commander");
const string_utils_1 = require("../../utils/string-utils");
const create_plugin_1 = require("./create-plugin");
const path_1 = __importDefault(require("path"));
const pluginCommand = new commander_1.Command("plugin");
exports.pluginCommand = pluginCommand;
pluginCommand.description("Create a new tsParticles plugin");
pluginCommand.argument("<destination>", "Destination folder");
pluginCommand.action(async (destination) => {
    const destPath = await (0, file_utils_1.getDestinationDir)(destination), repoUrl = await (0, file_utils_1.getRepositoryUrl)(), initialName = destPath.split(path_1.default.sep).pop(), questions = [
        {
            type: "text",
            name: "name",
            message: "What is the name of the plugin?",
            validate: (value) => (value ? true : "The name can't be empty"),
            initial: initialName,
        },
        {
            type: "text",
            name: "description",
            message: "What is the description of the plugin?",
            validate: (value) => (value ? true : "The description can't be empty"),
            initial: (0, string_utils_1.capitalize)(initialName ?? ""),
        },
        {
            type: "text",
            name: "repositoryUrl",
            message: "What is the repository URL? (optional)",
            initial: repoUrl.trim(),
        },
    ], { name, description, repositoryUrl } = (await (0, prompts_1.default)(questions));
    await (0, create_plugin_1.createPluginTemplate)(name.trim(), description.trim(), repositoryUrl.trim(), destPath);
});
