"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRepositoryUrl = exports.getDestinationDir = exports.replaceTokensInFile = exports.replaceTokensInFiles = void 0;
const child_process_1 = require("child_process");
const fs_extra_1 = __importDefault(require("fs-extra"));
const lookpath_1 = require("lookpath");
const path_1 = __importDefault(require("path"));
/**
 *
 * @param options -
 */
async function replaceTokensInFiles(options) {
    for (const item of options) {
        const filePath = path_1.default.resolve(item.path);
        let data = await fs_extra_1.default.readFile(filePath, "utf-8");
        for (const token of item.tokens) {
            const regex = new RegExp(token.from, "g");
            data = data.replace(regex, token.to);
        }
        await fs_extra_1.default.writeFile(filePath, data);
    }
}
exports.replaceTokensInFiles = replaceTokensInFiles;
/**
 *
 * @param options -
 */
async function replaceTokensInFile(options) {
    await replaceTokensInFiles([options]);
}
exports.replaceTokensInFile = replaceTokensInFile;
/**
 *
 * @param destination -
 * @returns the destination directory path
 */
async function getDestinationDir(destination) {
    const destPath = path_1.default.resolve(path_1.default.join(process.cwd(), destination)), destExists = await fs_extra_1.default.pathExists(destPath);
    if (destExists) {
        const destContents = await fs_extra_1.default.readdir(destPath), destContentsNoGit = destContents.filter(t => t !== ".git" && t !== ".gitignore");
        if (destContentsNoGit.length) {
            throw new Error("Destination folder already exists and is not empty");
        }
    }
    await fs_extra_1.default.ensureDir(destPath);
    return destPath;
}
exports.getDestinationDir = getDestinationDir;
/**
 * @returns the repository URL
 */
async function getRepositoryUrl() {
    if (!(await (0, lookpath_1.lookpath)("git"))) {
        return "";
    }
    return new Promise((resolve, reject) => {
        (0, child_process_1.exec)("git config --get remote.origin.url", (error, stdout) => {
            if (error) {
                reject(error);
                return;
            }
            resolve(stdout.toString());
        });
    });
}
exports.getRepositoryUrl = getRepositoryUrl;
